@@ -50,7 +50,8 @@ _QT_METADATA = {
     'QtGui': (
         VersionedMetadata(version=(6, 2, 0),
                 lib_deps={
-                        'linux': ('QtWaylandClient',
+                        'linux': ('QtEglFSDeviceIntegration',
+                                'QtWaylandClient',
                                 'QtWaylandEglClientHwIntegration',
                                 'QtWlShellIntegration', 'QtXcbQpa')},
                 other_lib_deps={
@@ -69,6 +70,15 @@ _QT_METADATA = {
         VersionedMetadata(version=(6, 8, 0),
                 lib_deps={'': ('QtMultimediaQuick', )},
                 other_lib_deps={
+                    'linux': (
+                            'libQt6FFmpegStub-crypto.so.3',
+                            'libQt6FFmpegStub-ssl.so.3',
+                            'libQt6FFmpegStub-va.so.2',
+                            'libQt6FFmpegStub-va-drm.so.2',
+                            'libQt6FFmpegStub-va-x11.so.2',
+                            'libavcodec.so.61', 'libavformat.so.61',
+                            'libavutil.so.59', 'libswresample.so.5',
+                            'libswscale.so.8'),
                     'macos': ('libavcodec.61.dylib', 'libavformat.61.dylib',
                             'libavutil.59.dylib', 'libswresample.5.dylib',
                             'libswscale.8.dylib'),
@@ -295,6 +305,10 @@ _QT_METADATA = {
     'QtSql':
         VersionedMetadata(),
 
+    'QtStateMachine':
+        VersionedMetadata(
+                lib_deps={'': ('QtStateMachineQml', )}),
+
     'QtSvg':
         VersionedMetadata(),
 
